<?php

namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Utilities;
use Teknisa\MAN\Factories;
use Teknisa\MAN\Services;

class Filial {

	protected $entityManager;
	protected $util;
	protected $filialFactory;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager,  Utilities\Util $util, Services\Filial $filialFactory)  {
		$this->entityManager = $entityManager;
		$this->util          = $util;
		$this->filialFactory = $filialFactory;
	}

	public function getFilial($CDFILIAL) {
		$params = array(
			'CDFILIAL' => $CDFILIAL
		);

		$filial = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL, $params);
		return $filial;
	}

	public function getFilialConsumidor($CDFILIAL) {
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_CONSUMIDOR, $params);
	}

	public function alteraPermissaoConsumidor($CDFILIAL, $DSACESSOSITE, $CDTIPOCONS) {
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':DSACESSOSITE' => $DSACESSOSITE,
			':CDTIPOCONS' => $CDTIPOCONS
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::ALTERA_PERMISSAO_CONSUMIDOR, $params);
	}

	public function buscaParametrosVenda($CDFILIAL){
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::BUSCA_PARAMETROS_VENDA_FILIAL, $params);
	}

	public function parametrizarVendaFilialParam($CDFILIAL, $IDUTLQTDPED){
		$params = array(
			':CDFILIAL'    => $CDFILIAL,
			':IDUTLQTDPED' => $IDUTLQTDPED
		);
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::ATUALIZA_PARAVEND_FILIAL_PARAMETRO, $params);
	}

	public function parametrizarVendaFilial($CDFILIAL, $NMFILIAL, $CDINTEGRADOTZ, $DSDIRARQDOTZ){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':NMFILIAL' 	 => $NMFILIAL,
			':CDINTEGRADOTZ' => $CDINTEGRADOTZ,
			':DSDIRARQDOTZ'  => $DSDIRARQDOTZ
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::ATUALIZA_PARAVEND_FILIAL, $params);
	}

	public function getFiliais ($FIRST, $LAST, $LABELFILIAL) {
		$params = array(
			':FIRST' 	 => $FIRST,
			':LAST' 	 => $LAST,
			':LABELFILIAL'  => $LABELFILIAL
		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAIS_MANAGE, $params);
	}

	public function filtroFilial($LABELFILIAL){
		$params = array(
			':LABELFILIAL' => $LABELFILIAL
		);

		$query = Utilities\Query::GET_FILTERED_FILIAIS;

		foreach (array_keys($params) as $name) {
			if(!empty($params[$name])){
				$query = $this->util->putArrayOnQuery($query, $name, $params[$name]);
				$params[$name] = '';
			}
			else{
				$params[$name] = 'null';
			}
		}

		$resultadoFiltrado = $this->entityManager->getConnection()->fetchAll($query, $params);
		return $resultadoFiltrado;
	}

	public function getParaVendDeli ($CDFILIAL) {
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL
		);
		
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_PARAMS_VEND_DELI, $params);
	}

	public function getFilialLojas($CDFILIAL){
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_LOJAS, $params);
	}

	public function getFilialOperadores($CDFILIAL){
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_OPERADORES, $params);
	}
	public function getFilialOperador($CDFILIAL, $CDOPERADOR){
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':CDOPERADOR' => $CDOPERADOR

		);

		$retorno = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_FILIAL_OPERADOR_EXPECIFICO, $params);
		return $retorno[0]['TEMPOPERADOR'];
	}
	public function getLojaOperador($CDFILIAL, $CDLOJA, $CDOPERADOR){
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':CDLOJA' => $CDLOJA,
			':CDOPERADOR' => $CDOPERADOR
		);

		$retorno = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJA_OPERADOR_EXPECIFICO, $params);
		return $retorno[0]['TEMPOPERADOR'];
	}

	public function getLojaOperadores($CDFILIAL, $CDLOJA){
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':CDLOJA' => $CDLOJA,

		);

		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJA_OPERADORES, $params);
	}

	public function loadIntegracoes() {		
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_INTEGRACOES);
	}

	public function loadIntegracao($CDINTEGRACAO) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_INTEGRACAO, $params);
	}

	public function loadRecebimento($CDINTEGRACAO, $CDTIPORECE) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':CDTIPORECE' 	    => $CDTIPORECE
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_RECEBIMENTO, $params);
	}

	public function deleteIntegracao($CDINTEGRACAO, $NRORG) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);	
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_INTEGRACAO, $params);
	}

	public function deleteRecebimento($CDINTEGRACAO, $CDTIPORECE, $NRORG) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':CDTIPORECE' 	    => $CDTIPORECE,
			':NRORG' 	        => $NRORG
		);	
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_RECEBIMENTO, $params);
	}

	public function adicionarIntegracao($NMINTEGRACAO, $IDINTEGRACAO, $CDINTEGRACAO, $NRORG){
		$params = array(
			':NMINTEGRACAO'		=> $NMINTEGRACAO,
			':IDINTEGRACAO' 	=> $IDINTEGRACAO, 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);		
		
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::INSERT_INTEGRACAO, $params);	
	}

	public function adicionarRecebimento($CDTIPORECE, $CDTPRECEINTE, $CDINTEGRACAO, $NRORG){
		$params = array(
			':CDTIPORECE'		=> $CDTIPORECE,
			':CDTPRECEINTE' 	=> $CDTPRECEINTE,
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);		
		
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::INSERT_RECEBIMENTO, $params);	
	}

	public function salvarRecebimento($CDTIPORECE, $CDTPRECEINTE, $oldCDTIPORECE, $CDINTEGRACAO, $NRORG){
		$params = array(
			':CDTIPORECE'		=> $CDTIPORECE,
			':CDTPRECEINTE' 	=> $CDTPRECEINTE,
			':oldCDTIPORECE' 	=> $oldCDTIPORECE,
			':CDINTEGRACAO' 	=> $CDINTEGRACAO,
			':NRORG' 	        => $NRORG
		);
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_RECEBIMENTO, $params);	
	}
	
	public function validaCodigoExterno($CDTPRECEINTE, $CDTIPORECE, $CDINTEGRACAO) {
		$params = array(
			':CDTPRECEINTE' => $CDTPRECEINTE,
			':CDTIPORECE'   => $CDTIPORECE,
			':CDINTEGRACAO' => $CDINTEGRACAO
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::VALIDACAO_CODIGO_EXTERNO, $params);
	}

	public function loadRecebimentosDisponiveisAdd($CDINTEGRACAO) {
		$params = array( 
			':CDINTEGRACAO' 	=> $CDINTEGRACAO
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_RECEBIMENTOS_ADD, $params);
	}
	
	public function loadRecebimentosDisponiveisInn($CDINTEGRACAO, $CDTIPORECE) {
		$params = array( 
			':CDINTEGRACAO' => $CDINTEGRACAO,
			':CDTIPORECE' 	=> $CDTIPORECE
		);	
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_RECEBIMENTOS_INN, $params);
	}
	
//-----------------
	public function setFilialOperador($CDFILIAL, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDOPERADOR' 	 => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::SET_FILIAL_OPERADOR, $params);
	}
	public function deleteFilialOperador($CDFILIAL, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDOPERADOR' 	 => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_FILIAL_OPERADOR, $params);
	}
	public function setLojaOperador($CDFILIAL, $CDLOJA, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDLOJA' 	     => $CDLOJA,
			':CDOPERADOR'    => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::SET_LOJA_OPERADOR, $params);
	}
	public function deleteLojaOperador($CDFILIAL, $CDLOJA, $CDOPERADOR){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL,
			':CDLOJA' 	     => $CDLOJA,
			':CDOPERADOR'    => $CDOPERADOR
		);

		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::DELETE_LOJA_OPERADOR, $params);
	}

	public function getStores($CDFILIAL){
		$params = array(
			':CDFILIAL' 	 => $CDFILIAL
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJAS_FILIAL, $params);

	}

	public function getFilialPayments($CDFILIAL) {
		$params = array(
			':CDFILIAL' => $CDFILIAL
		);

		$response = array( 
			array(
				'name' => "BRADESCO",
				'STATUS' => true,
				'value'  => 1
			),
			 array(
				'name'   => "ITAU",
				'STATUS' => true,
				'value'  => 2
			),
			array(
				'name'   => "BANCO DO BRASIL",
				'STATUS' => true,
				'value'  => 3
			)
		);

		return $response;
	}

	public function saveNutriRecomendation($DSRECOMENDNUTRI,$CDFILIAL){
		$params = array(
			'CDFILIAL' 	 => $CDFILIAL,
			'DSRECOMENDNUTRI' => $DSRECOMENDNUTRI
		);
		return $this->entityManager->getConnection()->executeQuery(Utilities\Query::UPDATE_NUTRI_RECOMENDATION, $params);
	}
	
	public function buscaFiliaisCliente($params) {
        $CDCLIENTE    = $params[0]['value'];
        $CDCONSUMIDOR = $params[1]['value'];
		$NRORG        = $params[2]['value'];
		$params = array(
			':CDCLIENTE'    => $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':NRORG'        => $NRORG
		);
		$result = $this->filialFactory->buscaFiliaisCliente($params);
		
		return $result;
	}
	
	public function buscaFiliaisConsumidor($params) {
        $CDCLIENTE    = $params[0]['value'];
		$CDCONSUMIDOR = $params[1]['value'];
		$NRORG        = $params[2]['value'];
		$params = array(
			':CDCLIENTE'    => $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':NRORG'        => $NRORG
		);
		$result = $this->filialFactory->buscaFiliaisConsumidor($params);
		
		return $result;
	}
	
	public function saveFiliaisConsumidor($params) {
        $CDCLIENTE         = $params[0]['value'];
        $CDCONSUMIDOR      = $params[1]['value'];
		$CDFILIAL          = $params[2]['value'];
		$NRORG             = $params[3]['value'];
		$params = array(
			':CDCLIENTE' 	=> $CDCLIENTE,
			':CDCONSUMIDOR' => $CDCONSUMIDOR,
			':CDFILIAL' 	=> $CDFILIAL
		);
		$this->filialFactory->saveFiliaisConsumidor($params);
	}
	
	public function removeFiliaisConsumidor ($params) {
        $CDCLIENTE         = $params[0]['CDCLIENTE'];
        $CDCONSUMIDOR      = $params[0]['CDCONSUMIDOR'];
        $CDFILIAL          = $params[0]['CDFILIAL'];
        
		$params = array(
			':CDCLIENTE' 	   => $CDCLIENTE,
			':CDCONSUMIDOR'    => $CDCONSUMIDOR,
			':CDFILIAL' 	   => $CDFILIAL
		);
		$this->filialFactory->removeFiliaisConsumidor($params);
	}
	
	public function validaParavend ($request){
		$params = $this->util->getParamsAsArray($request);
		
		$conditions = array(
			':NRORG'	=> $params['NRORG'],
			':CDFILIAL' => $params['CDFILIAL']
		);
		
		$result = $this->entityManager->getConnection()->fetchAll(self::COUNT_PARAVEND, $conditions)[0]['COUNT(*)'];
			if($result == 0)
				{
					$conditions = array(
						':CDFILIAL' 	=> $params['CDFILIAL'],
						':CDPARAVEND'	=> '1');
					$this->insertParavend($conditions);
				}
		return true;		
	} 
	
	public function updateDefNfce($params){
		$query = $this->entityManager->getConnection()->executeQuery(self::UPDATE_CERTIFICADO_NFCE, $params);
		return $query;
	}
	
	
	public function updateIntegracaoDeliveryFilial ($rows){
		$rows = $rows[0];
		$params = array(
			'CDFILIALEXT' =>$rows['CDFILIALEXT'],
			'CDFILIALEXTSPOON' => $rows['CDFILIALEXTSPOON'],
			'CDFILIAL'=>$rows['CDFILIAL'],
			'NRORG'=>$rows['NRORG']
		);
		
		$this->entityManager->getConnection()->executeQuery(self::UPDATE_INTEGRACAO_DELIVERY_FILIAL, $params);
	}
	
	const COUNT_PARAVEND = "SELECT COUNT(*) 
							  FROM PARAVEND
							WHERE NRORG = :NRORG
							  AND CDFILIAL = :CDFILIAL";

	const UPDATE_CERTIFICADO_NFCE = "UPDATE
										PARAVEND SET NMARQCERTNFCE = :NMARQCERTNFCE, DSSENHACERTNFCE = :DSSENHACERTNFCE
									WHERE
									  CDFILIAL = :CDFILIAL
									AND NRORG = :NRORG";
									
	const UPDATE_INTEGRACAO_DELIVERY_FILIAL = "
		UPDATE FILIAL 
			SET CDFILIALEXT = :CDFILIALEXT , CDFILIALEXTSPOON = :CDFILIALEXTSPOON
		WHERE
			CDFILIAL = :CDFILIAL
			AND NRORG = :NRORG
		
	";
	
}